@@ -70,7 +70,8 @@ with requests.Session() as session:
                 PayloadDetailSdk(
                     __version__,
                     installed_packages
-                )
+                ),
+                user_info
             )
         ]
 
@@ -119,7 +120,8 @@ with requests.Session() as session:
                 PayloadDetailSdk(
                     __version__,
                     installed_packages
-                )
+                ),
+                user_info
             )
         ]
 
